@@ -31,7 +31,7 @@ __author__ = 'Mansour Behabadi'
 __copyright__ = 'Copyright 2011, Mansour Behabadi and Jake Gordon'
 __credits__ = ['Mansour Behabadi', 'Jake Gordon']
 __license__ = 'MIT'
-__version__ = '1.1.2'
+__version__ = '2.0.0'
 __maintainer__ = 'Mansour Behabadi'
 __email__ = 'mansour@oxplot.com'
 
@@ -50,6 +50,14 @@ class FysomError(Exception):
     pass
 
 
+class Canceled(FysomError):
+
+    '''
+        Raised when an event is canceled due to the
+        onbeforeevent handler returning False
+    '''
+
+
 class Fysom(object):
 
     '''
@@ -230,7 +238,8 @@ class Fysom(object):
 
             # Try to trigger the before event, unless it gets canceled.
             if self._before_event(e) is False:
-                return
+                raise Canceled(
+                    "Cannot trigger event {0} because the onbefore{0} handler returns False".format(e.event))
 
             # Wraps the activities that must constitute a single successful transaction.
             if self.current != dst:
